==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AuthenticationFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AuthenticationFluent<A extends AuthenticationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public AuthenticationFluent.MetadataNested<A> withNewMetadata();
  public AuthenticationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public AuthenticationFluent.MetadataNested<A> editMetadata();
  public AuthenticationFluent.MetadataNested<A> editOrNewMetadata();
  public AuthenticationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public AuthenticationSpec getSpec();
  public AuthenticationSpec buildSpec();
  public A withSpec(AuthenticationSpec spec);
  public Boolean hasSpec();
  public AuthenticationFluent.SpecNested<A> withNewSpec();
  public AuthenticationFluent.SpecNested<A> withNewSpecLike(AuthenticationSpec item);
  public AuthenticationFluent.SpecNested<A> editSpec();
  public AuthenticationFluent.SpecNested<A> editOrNewSpec();
  public AuthenticationFluent.SpecNested<A> editOrNewSpecLike(AuthenticationSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public AuthenticationStatus getStatus();
  public AuthenticationStatus buildStatus();
  public A withStatus(AuthenticationStatus status);
  public Boolean hasStatus();
  public AuthenticationFluent.StatusNested<A> withNewStatus();
  public AuthenticationFluent.StatusNested<A> withNewStatusLike(AuthenticationStatus item);
  public AuthenticationFluent.StatusNested<A> editStatus();
  public AuthenticationFluent.StatusNested<A> editOrNewStatus();
  public AuthenticationFluent.StatusNested<A> editOrNewStatusLike(AuthenticationStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<AuthenticationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,AuthenticationSpecFluent<AuthenticationFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,AuthenticationStatusFluent<AuthenticationFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AuthenticationFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AuthenticationFluent<A extends AuthenticationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public AuthenticationFluent.MetadataNested<A> withNewMetadata();
  public AuthenticationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public AuthenticationFluent.MetadataNested<A> editMetadata();
  public AuthenticationFluent.MetadataNested<A> editOrNewMetadata();
  public AuthenticationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public AuthenticationSpec getSpec();
  public AuthenticationSpec buildSpec();
  public A withSpec(AuthenticationSpec spec);
  public Boolean hasSpec();
  public AuthenticationFluent.SpecNested<A> withNewSpec();
  public AuthenticationFluent.SpecNested<A> withNewSpecLike(AuthenticationSpec item);
  public AuthenticationFluent.SpecNested<A> editSpec();
  public AuthenticationFluent.SpecNested<A> editOrNewSpec();
  public AuthenticationFluent.SpecNested<A> editOrNewSpecLike(AuthenticationSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public AuthenticationStatus getStatus();
  public AuthenticationStatus buildStatus();
  public A withStatus(AuthenticationStatus status);
  public Boolean hasStatus();
  public AuthenticationFluent.StatusNested<A> withNewStatus();
  public AuthenticationFluent.StatusNested<A> withNewStatusLike(AuthenticationStatus item);
  public AuthenticationFluent.StatusNested<A> editStatus();
  public AuthenticationFluent.StatusNested<A> editOrNewStatus();
  public AuthenticationFluent.StatusNested<A> editOrNewStatusLike(AuthenticationStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<AuthenticationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,AuthenticationSpecFluent<AuthenticationFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,AuthenticationStatusFluent<AuthenticationFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
